@@ -51,7 +51,7 @@ KIGPDialog::KIGPDialog(QWidget *parent, const QString& path, const char *name )
 {
     m_path = path;
     setCaption(i18n("Create Image Gallery"));
-    setButtonOKText( i18n("Create") );
+    setButtonOK( KGuiItem(i18n("Create"),"imagegallery") );
     m_config = new KConfig("kimgallerypluginrc", false, false);
     setupLookPage(path);
     setupDirectoryPage(path);
@@ -77,7 +77,7 @@ void KIGPDialog::slotDefault()
     m_useCommentFile->setChecked( false );
     m_commentFileReq->setURL(m_path + "comments");
     m_commentFileReq->setEnabled( false );
-    
+
     m_imageFormat->setCurrentText( "JPEG");
     m_thumbnailSize->setValue(140);
     m_colorDepthSet->setChecked(false);
@@ -182,7 +182,7 @@ void KIGPDialog::setupDirectoryPage(const QString& path) {
     QVBoxLayout *dvlay = new QVBoxLayout( page, 0, spacingHint() );
 
     QLabel *label;
-    label = new QLabel(i18n("&Save to:"), page);
+    label = new QLabel(i18n("&Save to HTML file:"), page);
     dvlay->addWidget( label );
     QString whatsThis;
     whatsThis = i18n("<p>The name of the HTML file this gallery will be saved to.");
